@@ -1,2 +1,2 @@
-from .templates import *
+from .handler import *
 from .function import train_test_split, train_model
